@@ -1,9 +1,18 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
 #include <sirius.hpp>
+#include <testing.hpp>
 
 using namespace sirius;
 
 int
-run_test()
+test_r3_geom()
 {
     r3::vector<double> a(1.1, 2.2, 3.3);
     r3::vector<double> b = a;
@@ -27,30 +36,5 @@ run_test()
 int
 main(int argn, char** argv)
 {
-    cmd_args args;
-
-    args.parse_args(argn, argv);
-    if (args.exist("help")) {
-        printf("Usage: %s [options]\n", argv[0]);
-        args.print_help();
-        return 0;
-    }
-
-    sirius::initialize(1);
-    printf("%-30s", "testing geometry3d: ");
-    int result = run_test();
-    if (result) {
-        printf("\x1b[31m"
-               "Failed"
-               "\x1b[0m"
-               "\n");
-    } else {
-        printf("\x1b[32m"
-               "OK"
-               "\x1b[0m"
-               "\n");
-    }
-    sirius::finalize();
-
-    return 0;
+    return call_test(argv[0], test_r3_geom);
 }
