@@ -1,3 +1,12 @@
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
+
+#include "k_point/k_point_set.hpp"
 #include "python_module_includes.hpp"
 #include <mpi.h>
 
@@ -8,6 +17,12 @@
 #include "make_sirius_comm.hpp"
 #include "dft/smearing.hpp"
 #include "hamiltonian/initialize_subspace.hpp"
+#include <pybind11/attr.h>
+#include <string>
+#include <vector>
+#include <list>
+#include <complex>
+#include <iostream>
 
 using namespace pybind11::literals;
 namespace py = pybind11;
@@ -70,6 +85,7 @@ pj_convert(json& node)
 /* typedefs */
 using complex_double = std::complex<double>;
 
+template <bool gamma_point = false>
 void
 apply_hamiltonian(Hamiltonian0<double>& H0, K_point<double>& kp, wf::Wave_functions<double>& wf_out,
                   wf::Wave_functions<double>& wf, std::shared_ptr<wf::Wave_functions<double>>& swf)
@@ -93,7 +109,11 @@ apply_hamiltonian(Hamiltonian0<double>& H0, K_point<double>& kp, wf::Wave_functi
     for (int ispn_step = 0; ispn_step < ctx.num_spinors(); ispn_step++) {
         // sping_range: 2 for non-colinear magnetism, otherwise ispn_step
         auto spin_range = wf::spin_range((ctx.num_mag_dims() == 3) ? 2 : ispn_step);
-        H.apply_h_s<complex_double>(spin_range, wf::band_range(N, N + n), wf, &wf_out, swf.get());
+        if constexpr (gamma_point) {
+            H.apply_h_s<double>(spin_range, wf::band_range(N, N + n), wf, &wf_out, swf.get());
+        } else {
+            H.apply_h_s<complex_double>(spin_range, wf::band_range(N, N + n), wf, &wf_out, swf.get());
+        }
     }
     if (is_device_memory(ctx.processing_unit_memory_t())) {
         if (swf) {
@@ -179,7 +199,9 @@ PYBIND11_MODULE(py_sirius, m)
             .def("processing_unit", py::overload_cast<std::string>(&Simulation_context::processing_unit))
             .def("gvec", &Simulation_context::gvec, py::return_value_policy::reference_internal)
             .def("full_potential", &Simulation_context::full_potential)
-            .def("hubbard_correction", &Simulation_context::hubbard_correction)
+            .def_property_readonly("hubbard_correction", &Simulation_context::hubbard_correction)
+            .def_property_readonly("kT", py::overload_cast<>(&Simulation_context::smearing_width, py::const_))
+            .def_property_readonly("smearing_type", py::overload_cast<>(&Simulation_context::smearing, py::const_))
             .def("unit_cell", py::overload_cast<>(&Simulation_context::unit_cell, py::const_),
                  py::return_value_policy::reference)
             .def("pw_cutoff", py::overload_cast<>(&Simulation_context::pw_cutoff, py::const_))
@@ -190,7 +212,7 @@ PYBIND11_MODULE(py_sirius, m)
             .def("aw_cutoff", py::overload_cast<double>(&Simulation_context::aw_cutoff))
             .def("num_spinors", &Simulation_context::num_spinors)
             .def("num_mag_dims", &Simulation_context::num_mag_dims)
-            .def("gamma_point", py::overload_cast<bool>(&Simulation_context::gamma_point))
+            .def_property_readonly("gamma_point", py::overload_cast<>(&Simulation_context::gamma_point, py::const_))
             .def("update", &Simulation_context::update)
             .def("use_symmetry", py::overload_cast<>(&Simulation_context::use_symmetry, py::const_))
             .def("processing_unit_memory_t", &Simulation_context::processing_unit_memory_t)
@@ -202,8 +224,7 @@ PYBIND11_MODULE(py_sirius, m)
                     py::return_value_policy::reference_internal)
             .def(
                     "comm_fft", [](Simulation_context& obj) { return make_pycomm(obj.comm_fft()); },
-                    py::return_value_policy::reference_internal)
-            .def("fft_grid", &Simulation_context::fft_grid, py::return_value_policy::reference_internal);
+                    py::return_value_policy::reference_internal);
 
     py::class_<Atom>(m, "Atom")
             .def("position", &Atom::position)
@@ -246,6 +267,7 @@ PYBIND11_MODULE(py_sirius, m)
             .def_property_readonly("num_electrons", &Unit_cell::num_electrons)
             .def_property_readonly("num_atoms", &Unit_cell::num_atoms)
             .def_property_readonly("num_valence_electrons", &Unit_cell::num_valence_electrons)
+            .def_property_readonly("augmented", &Unit_cell::augment)
             .def_property_readonly("reciprocal_lattice_vectors", &Unit_cell::reciprocal_lattice_vectors)
             .def("generate_radial_functions", &Unit_cell::generate_radial_functions)
             .def_property_readonly("min_mt_radius", &Unit_cell::min_mt_radius)
@@ -432,15 +454,16 @@ PYBIND11_MODULE(py_sirius, m)
 
     py::class_<Force>(m, "Force")
             .def(py::init<Simulation_context&, Density&, Potential&, K_point_set&>())
-            .def("calc_forces_total", &Force::calc_forces_total, py::return_value_policy::reference_internal)
-            .def_property_readonly("ewald", &Force::forces_ewald)
-            .def_property_readonly("hubbard", &Force::forces_hubbard)
-            .def_property_readonly("vloc", &Force::forces_vloc)
-            .def_property_readonly("nonloc", &Force::forces_nonloc)
-            .def_property_readonly("core", &Force::forces_core)
-            .def_property_readonly("scf_corr", &Force::forces_scf_corr)
-            .def_property_readonly("us", &Force::forces_us)
-            .def_property_readonly("total", &Force::forces_total)
+            .def("calc_forces_total", py::overload_cast<bool>(&Force::calc_forces_total), "add_scf_corr"_a,
+                 py::return_value_policy::reference_internal)
+            .def_property_readonly("ewald", &Force::forces_ewald, py::return_value_policy::reference_internal)
+            .def_property_readonly("hubbard", &Force::forces_hubbard, py::return_value_policy::reference_internal)
+            .def_property_readonly("vloc", &Force::forces_vloc, py::return_value_policy::reference_internal)
+            .def_property_readonly("nonloc", &Force::forces_nonloc, py::return_value_policy::reference_internal)
+            .def_property_readonly("core", &Force::forces_core, py::return_value_policy::reference_internal)
+            .def_property_readonly("scf_corr", &Force::forces_scf_corr, py::return_value_policy::reference_internal)
+            .def_property_readonly("us", &Force::forces_us, py::return_value_policy::reference_internal)
+            .def_property_readonly("total", &Force::forces_total, py::return_value_policy::reference_internal)
             .def("print_info", &Force::print_info);
 
     py::class_<fft::Grid>(m, "FFT3D_grid")
@@ -492,7 +515,6 @@ PYBIND11_MODULE(py_sirius, m)
             });
 
     py::enum_<device_t>(m, "DeviceEnum").value("CPU", device_t::CPU).value("GPU", device_t::GPU);
-
     py::enum_<memory_t>(m, "MemoryEnum").value("device", memory_t::device).value("host", memory_t::host);
     py::enum_<wf::copy_to>(m, "CopyEnum")
             .value("none", wf::copy_to::none)
@@ -502,9 +524,11 @@ PYBIND11_MODULE(py_sirius, m)
     py::class_<wf::num_bands>(m, "num_bands").def(py::init<int>());
     py::class_<fft::Gvec_fft, std::shared_ptr<fft::Gvec_fft>>(m, "Gvec_fft");
     py::class_<fft::Gvec, std::shared_ptr<fft::Gvec>>(m, "Gvec")
-            .def("count", &fft::Gvec::count)
-            .def("gkvec_cart", &fft::Gvec::gkvec_cart<index_domain_t::global>);
-    // use std::shared_ptr as holder type, this required by Hamiltonian.apply_ref, apply_ref_inner
+            .def("count", py::overload_cast<>(&fft::Gvec::count, py::const_))
+            .def("gkvec_cart", [](py::object& gvec_obj, int i) {
+                auto& gvec = gvec_obj.cast<fft::Gvec&>();
+                return gvec.gkvec_cart(gvec_index_t::global(i));
+            });
     py::class_<wf::device_memory_guard>(m, "device_memory_guard");
 
     py::class_<wf::Wave_functions_base<double>, std::shared_ptr<wf::Wave_functions_base<double>>>(m,
@@ -520,10 +544,11 @@ PYBIND11_MODULE(py_sirius, m)
                  "num_mag_dims"_a, "mum_bands"_a, "memory_t"_a)
             .def("num_sc", &wf::Wave_functions<double>::num_sc)
             .def("num_wf", &wf::Wave_functions<double>::num_wf)
-            // .def("has_mt", &wf::Wave_functions<double>::has_mt)
-            // .def("zero_pw", &wf::Wave_functions<double>::zero_pw)
-            // .def("preferred_memory_t", py::overload_cast<>(&wf::Wave_functions<double>::preferred_memory_t,
-            // py::const_))
+            .def("zero",
+                 [](wf::Wave_functions<double>& wf) {
+                     for (int i = 0; i < wf.num_md(); ++i)
+                         wf.pw_coeffs(wf::spin_index(i)).zero();
+                 })
             .def(
                     "pw_coeffs",
                     [](py::object& obj, int i) -> py::array_t<complex_double> {
@@ -559,6 +584,9 @@ PYBIND11_MODULE(py_sirius, m)
     py::class_<Periodic_function<double>>(m, "RPeriodic_function");
 
     m.def("total_energy", &total_energy);
+    m.def("ks_energy",
+          py::overload_cast<Simulation_context const&, K_point_set const&, Density const&, Potential const&>(
+                  &ks_energy));
     m.def("ewald_energy", &ewald_energy);
     m.def("set_atom_positions", &set_atom_positions);
     m.def("atom_positions", &atom_positions);
@@ -569,7 +597,9 @@ PYBIND11_MODULE(py_sirius, m)
     m.def("make_pycomm", &make_pycomm);
     m.def("magnetization", &magnetization);
     m.def("sprint_magnetization", &sprint_magnetization);
-    m.def("apply_hamiltonian", &apply_hamiltonian, "Hamiltonian0"_a, "kpoint"_a, "wf_out"_a, "wf_in"_a,
+    m.def("apply_hamiltonian", &apply_hamiltonian<>, "Hamiltonian0"_a, "kpoint"_a, "wf_out"_a, "wf_in"_a,
+          py::arg("swf_out") = nullptr);
+    m.def("apply_hamiltonian_gamma", &apply_hamiltonian<true>, "Hamiltonian0"_a, "kpoint"_a, "wf_out"_a, "wf_in"_a,
           py::arg("swf_out") = nullptr);
 
     m.def("initialize_subspace", &initialize_subspace<double, std::complex<double>>);
@@ -577,12 +607,17 @@ PYBIND11_MODULE(py_sirius, m)
 
     /* sirius.smearing submodules */
     py::module smearing_module = m.def_submodule("smearing");
+    py::enum_<smearing::smearing_t>(smearing_module, "SmearingEnum")
+            .value("gauss", smearing::smearing_t::gaussian)
+            .value("methfessel_paxton", smearing::smearing_t::methfessel_paxton)
+            .value("fermi_dirac", smearing::smearing_t::fermi_dirac)
+            .value("cold", smearing::smearing_t::cold);
     {
         py::module mpm = smearing_module.def_submodule("methfessel_paxton");
-        mpm.def("entropy", py::vectorize(&smearing::methfessel_paxton::entropy), "x"_a, "w"_a, "n"_a);
-        mpm.def("delta", py::vectorize(&smearing::methfessel_paxton::delta), "x"_a, "w"_a, "n"_a);
-        mpm.def("occupancy", py::vectorize(&smearing::methfessel_paxton::occupancy), "x"_a, "w"_a, "n"_a);
-        mpm.def("dxdelta", py::vectorize(&smearing::methfessel_paxton::dxdelta), "x"_a, "w"_a, "n"_a);
+        mpm.def("entropy", py::vectorize(&smearing::methfessel_paxton::entropy), "x"_a, "w"_a, "n"_a = int{1});
+        mpm.def("delta", py::vectorize(&smearing::methfessel_paxton::delta), "x"_a, "w"_a, "n"_a = int{1});
+        mpm.def("occupancy", py::vectorize(&smearing::methfessel_paxton::occupancy), "x"_a, "w"_a, "n"_a = int{1});
+        mpm.def("dxdelta", py::vectorize(&smearing::methfessel_paxton::dxdelta), "x"_a, "w"_a, "n"_a = int{1});
     }
     {
         py::module mcold = smearing_module.def_submodule("cold");
@@ -602,6 +637,7 @@ PYBIND11_MODULE(py_sirius, m)
         py::module mgauss = smearing_module.def_submodule("gaussian");
         mgauss.def("delta", py::vectorize(&smearing::gaussian::delta), "x"_a, "w"_a);
         mgauss.def("occupancy", py::vectorize(&smearing::gaussian::occupancy), "x"_a, "w"_a);
+        mgauss.def("entropy", py::vectorize(&smearing::gaussian::entropy), "x"_a, "w"_a);
     }
     /* sirius.smearing submodules (end) */
 }
