@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2020 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file linalg.hpp
  *
@@ -27,6 +16,7 @@
 
 #include <stdint.h>
 #include "core/memory.hpp"
+#include "core/rte/rte.hpp"
 #include "core/acc/acc.hpp"
 #if defined(SIRIUS_GPU)
 #include "core/acc/acc_blas.hpp"
@@ -181,14 +171,16 @@ class wrap
         std::vector<int> ipiv(n);
         int info = this->getrf(n, n, A.at(memory_t::host), A.ld(), &ipiv[0]);
         if (info) {
-            std::printf("getrf returned %i\n", info);
-            exit(-1);
+            std::stringstream s;
+            s << "getrf returned with non-zero info : " << info;
+            RTE_THROW(s);
         }
 
         info = this->getri(n, A.at(memory_t::host), A.ld(), &ipiv[0]);
         if (info) {
-            std::printf("getri returned %i\n", info);
-            exit(-1);
+            std::stringstream s;
+            s << "getri returned with non-zero info : " << info;
+            RTE_THROW(s);
         }
     }
 
@@ -199,14 +191,16 @@ class wrap
         std::vector<int> ipiv(n);
         int info = this->sytrf(n, A.at(memory_t::host), A.ld(), &ipiv[0]);
         if (info) {
-            std::printf("sytrf returned %i\n", info);
-            exit(-1);
+            std::stringstream s;
+            s << "sytrf returned with non-zero info : " << info;
+            RTE_THROW(s);
         }
 
         info = this->sytri(n, A.at(memory_t::host), A.ld(), &ipiv[0]);
         if (info) {
-            std::printf("sytri returned %i\n", info);
-            exit(-1);
+            std::stringstream s;
+            s << "sytri returned with non-zero info : " << info;
+            RTE_THROW(s);
         }
     }
 
@@ -216,8 +210,9 @@ class wrap
     {
         std::vector<int> ipiv(n);
         int info = this->sytrf(n, A.at(memory_t::host), A.ld(), ipiv.data());
-        if (info)
+        if (info) {
             return false;
+        }
 
         info = this->sytrs(n, 1, A.at(memory_t::host), A.ld(), ipiv.data(), b.at(memory_t::host), b.ld());
 
@@ -1997,6 +1992,7 @@ wrap::lartg(ftn_double f, ftn_double g) const
     switch (la_) {
         case lib_t::lapack: {
             FORTRAN(dlartg)(&f, &g, &cs, &sn, &r);
+            return std::make_tuple(cs, sn, r);
         }
         default: {
             RTE_THROW(linalg_msg_wrong_type);
