@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2018 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file dft_ground_state.hpp
  *
@@ -68,9 +57,6 @@ class DFT_ground_state
     /// k-point independent part of the Hamiltonian.
     std::shared_ptr<Hamiltonian0<double>> H0_; // hard-code double for now
 
-    /// Store Ewald energy which is computed once and which doesn't change during the run.
-    double ewald_energy_{0};
-
     /// Correction to total energy from the SCF density minimisation.
     double scf_correction_energy_{0};
 
@@ -86,10 +72,8 @@ class DFT_ground_state
         , forces_(ctx_, density_, potential_, kset__)
 
     {
-        if (!ctx_.full_potential()) {
-            ewald_energy_ = sirius::ewald_energy(ctx_, ctx_.gvec(), ctx_.unit_cell());
-        }
     }
+
     ~DFT_ground_state()
     {
         int n = ctx_.num_loc_op_applied();
@@ -152,12 +136,6 @@ class DFT_ground_state
         return stress_;
     }
 
-    inline double
-    ewald_energy() const
-    {
-        return ewald_energy_;
-    }
-
     inline double
     scf_correction_energy() const
     {
