@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2020 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file energy.cpp
  *
@@ -27,19 +16,19 @@
 namespace sirius {
 
 double
-ewald_energy(const Simulation_context& ctx, const fft::Gvec& gvec, const Unit_cell& unit_cell)
+ewald_energy(Simulation_context const& ctx, fft::Gvec const& gvec, Unit_cell const& unit_cell)
 {
     double alpha{ctx.ewald_lambda()};
     double ewald_g{0};
 
     #pragma omp parallel for reduction(+ : ewald_g)
     for (int igloc = gvec.skip_g0(); igloc < gvec.count(); igloc++) {
-        double g2 = std::pow(gvec.gvec_len<index_domain_t::local>(igloc), 2);
+        double g2 = std::pow(gvec.gvec_len(gvec_index_t::local(igloc)), 2);
 
         std::complex<double> rho(0, 0);
 
         for (int ia = 0; ia < unit_cell.num_atoms(); ia++) {
-            rho += ctx.gvec_phase_factor(gvec.gvec<index_domain_t::local>(igloc), ia) *
+            rho += ctx.gvec_phase_factor(gvec.gvec(gvec_index_t::local(igloc)), ia) *
                    static_cast<double>(unit_cell.atom(ia).zn());
         }
 
@@ -91,7 +80,7 @@ energy_vha(Potential const& potential)
 }
 
 double
-energy_bxc(const Density& density, const Potential& potential)
+energy_bxc(Density const& density, Potential const& potential)
 {
     double ebxc{0};
     for (int j = 0; j < density.ctx().num_mag_dims(); j++) {
@@ -150,7 +139,7 @@ energy_kin(Simulation_context const& ctx, K_point_set const& kset, Density const
 }
 
 double
-ks_energy(Simulation_context const& ctx, const std::map<std::string, double>& energies)
+ks_energy(Simulation_context const& ctx, std::map<std::string, double> const& energies)
 {
     double tot_en{0};
 
@@ -176,41 +165,28 @@ ks_energy(Simulation_context const& ctx, const std::map<std::string, double>& en
 }
 
 double
-ks_energy(Simulation_context const& ctx, K_point_set const& kset, Density const& density, Potential const& potential,
-          double ewald_energy)
+ks_energy(Simulation_context const& ctx, K_point_set const& kset, Density const& density, Potential const& potential)
 {
-    return ks_energy(ctx, total_energy_components(ctx, kset, density, potential, ewald_energy));
+    return ks_energy(ctx, total_energy_components(ctx, kset, density, potential));
 }
 
+/** Total energy is an alias for Kohn-Sham total energy. It is computed without entropy contribution. */
 double
-total_energy(Simulation_context const& ctx, K_point_set const& kset, Density const& density, Potential const& potential,
-             double ewald_energy)
+total_energy(Simulation_context const& ctx, K_point_set const& kset, Density const& density, Potential const& potential)
 {
+    return ks_energy(ctx, kset, density, potential);
+}
 
-    double eks = ks_energy(ctx, kset, density, potential, ewald_energy);
-    double tot_en{0};
-
-    switch (ctx.electronic_structure_method()) {
-        case electronic_structure_method_t::full_potential_lapwlo: {
-            tot_en = eks;
-            break;
-        }
-
-        case electronic_structure_method_t::pseudopotential: {
-            tot_en = eks + kset.entropy_sum();
-            break;
-        }
-        default: {
-            RTE_THROW("invalid electronic_structure_method");
-        }
-    }
-
-    return tot_en;
+/** F = E - TS, where -TS is the entropy sum. */
+double
+free_energy(Simulation_context const& ctx, K_point_set const& kset, Density const& density, Potential const& potential)
+{
+    return ks_energy(ctx, kset, density, potential) + kset.entropy_sum();
 }
 
 std::map<std::string, double>
-total_energy_components(Simulation_context const& ctx, const K_point_set& kset, Density const& density,
-                        Potential const& potential, double ewald_energy)
+total_energy_components(Simulation_context const& ctx, K_point_set const& kset, Density const& density,
+                        Potential const& potential)
 {
     std::map<std::string, double> table;
     switch (ctx.electronic_structure_method()) {
@@ -229,7 +205,7 @@ total_energy_components(Simulation_context const& ctx, const K_point_set& kset,
             table["PAW_one_elec"]     = potential.PAW_one_elec_energy(density);
             table["vha"]              = energy_vha(potential);
             table["exc"]              = energy_exc(density, potential);
-            table["ewald"]            = ewald_energy;
+            table["ewald"]            = potential.ewald_energy();
             table["PAW_total_energy"] = potential.PAW_total_energy(density);
             break;
         }
