@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2019 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file stress.cpp
  *
@@ -136,7 +125,6 @@ Stress::calc_stress_hubbard()
         if (is_device_memory(ctx_.processing_unit_memory_t())) {
             dn.zero(ctx_.processing_unit_memory_t());
         }
-        // kp->beta_projectors().prepare();
         auto mg1 = kp->spinor_wave_functions().memory_guard(ctx_.processing_unit_memory_t(), wf::copy_to::device);
         auto mg2 = kp->hubbard_wave_functions_S().memory_guard(ctx_.processing_unit_memory_t(), wf::copy_to::device);
         auto mg3 = kp->atomic_wave_functions().memory_guard(ctx_.processing_unit_memory_t(), wf::copy_to::device);
@@ -238,14 +226,13 @@ Stress::calc_stress_core()
 
     auto q        = ctx_.gvec().shells_len();
     auto const ff = ctx_.ri().ps_core_djl_->values(q, ctx_.comm());
-    auto drhoc =
-            make_periodic_function<index_domain_t::local>(ctx_.unit_cell(), ctx_.gvec(), ctx_.phase_factors_t(), ff);
+    auto drhoc    = make_periodic_function<true>(ctx_.unit_cell(), ctx_.gvec(), ctx_.phase_factors_t(), ff);
 
     double sdiag{0};
     int ig0 = ctx_.gvec().skip_g0();
 
     for (int igloc = ig0; igloc < ctx_.gvec().count(); igloc++) {
-        auto G = ctx_.gvec().gvec_cart<index_domain_t::local>(igloc);
+        auto G = ctx_.gvec().gvec_cart(gvec_index_t::local(igloc));
         auto g = G.length();
 
         for (int mu : {0, 1, 2}) {
@@ -445,7 +432,7 @@ Stress::calc_stress_us()
                     }
                     #pragma omp parallel for
                     for (int igloc = igloc0; igloc < ctx_.gvec().count(); igloc++) {
-                        auto gvc = ctx_.gvec().gvec_cart<index_domain_t::local>(igloc);
+                        auto gvc = ctx_.gvec().gvec_cart(gvec_index_t::local(igloc));
                         double g = gvc.length();
 
                         for (int ia = 0; ia < atom_type.num_atoms(); ia++) {
@@ -501,7 +488,7 @@ Stress::calc_stress_ewald()
     for (int igloc = ig0; igloc < ctx_.gvec().count(); igloc++) {
         int ig = ctx_.gvec().offset() + igloc;
 
-        auto G          = ctx_.gvec().gvec_cart<index_domain_t::local>(igloc);
+        auto G          = ctx_.gvec().gvec_cart(gvec_index_t::local(igloc));
         double g2       = std::pow(G.length(), 2);
         double g2lambda = g2 / 4.0 / lambda;
 
@@ -616,7 +603,7 @@ Stress::calc_stress_har()
 
     int ig0 = ctx_.gvec().skip_g0();
     for (int igloc = ig0; igloc < ctx_.gvec().count(); igloc++) {
-        auto G    = ctx_.gvec().gvec_cart<index_domain_t::local>(igloc);
+        auto G    = ctx_.gvec().gvec_cart(gvec_index_t::local(igloc));
         double g2 = std::pow(G.length(), 2);
         auto z    = density_.rho().rg().f_pw_local(igloc);
         double d  = twopi * (std::pow(z.real(), 2) + std::pow(z.imag(), 2)) / g2;
@@ -661,7 +648,7 @@ Stress::calc_stress_kin_aux()
                 #pragma omp for
                 for (int i = 0; i < kp->num_occupied_bands(ispin); i++) {
                     for (int igloc = 0; igloc < kp->num_gkvec_loc(); igloc++) {
-                        auto Gk = kp->gkvec().template gkvec_cart<index_domain_t::local>(igloc);
+                        auto Gk = kp->gkvec().gkvec_cart(gvec_index_t::local(igloc));
 
                         double f = kp->band_occupancy(i, ispin);
                         auto z = kp->spinor_wave_functions().pw_coeffs(igloc, wf::spin_index(ispin), wf::band_index(i));
@@ -711,17 +698,15 @@ Stress::calc_stress_vloc()
     auto const ri_vloc    = ctx_.ri().vloc_->values(q, ctx_.comm());
     auto const ri_vloc_dg = ctx_.ri().vloc_djl_->values(q, ctx_.comm());
 
-    auto v  = make_periodic_function<index_domain_t::local>(ctx_.unit_cell(), ctx_.gvec(), ctx_.phase_factors_t(),
-                                                           ri_vloc);
-    auto dv = make_periodic_function<index_domain_t::local>(ctx_.unit_cell(), ctx_.gvec(), ctx_.phase_factors_t(),
-                                                            ri_vloc_dg);
+    auto v  = make_periodic_function<true>(ctx_.unit_cell(), ctx_.gvec(), ctx_.phase_factors_t(), ri_vloc);
+    auto dv = make_periodic_function<true>(ctx_.unit_cell(), ctx_.gvec(), ctx_.phase_factors_t(), ri_vloc_dg);
 
     double sdiag{0};
 
     int ig0 = ctx_.gvec().skip_g0();
     for (int igloc = ig0; igloc < ctx_.gvec().count(); igloc++) {
 
-        auto G = ctx_.gvec().gvec_cart<index_domain_t::local>(igloc);
+        auto G = ctx_.gvec().gvec_cart(gvec_index_t::local(igloc));
 
         for (int mu : {0, 1, 2}) {
             for (int nu : {0, 1, 2}) {
