@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2018 Mathieu Taillefumier, Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file hubbard_potential_energy.hpp
  *
@@ -54,16 +43,14 @@ generate_potential_collinear_nonlocal(Simulation_context const& ctx__, const int
 {
     auto nl = ctx__.cfg().hubbard().nonlocal(index__);
     um__.zero();
-
-    double v_ij = nl.V() / ha2ev;
-    int il      = nl.l()[0];
-    int jl      = nl.l()[1];
+    const int il = nl.l()[0];
+    const int jl = nl.l()[1];
     um__.zero();
     // second term of Eq. 2
     for (int is = 0; is < ctx__.num_spins(); is++) {
         for (int m2 = 0; m2 < 2 * jl + 1; m2++) {
             for (int m1 = 0; m1 < 2 * il + 1; m1++) {
-                um__(m1, m2, is) = -v_ij * om__(m1, m2, is);
+                um__(m1, m2, is) = -nl.V() * om__(m1, m2, is);
             }
         }
     }
@@ -219,15 +206,15 @@ calculate_energy_collinear_nonlocal(Simulation_context const& ctx__, const int i
 {
     auto nl = ctx__.cfg().hubbard().nonlocal(index__);
     double hubbard_energy{0.0};
-    double v_ij_ = nl.V() / ha2ev;
-    int il       = nl.l()[0];
-    int jl       = nl.l()[1];
+
+    const int il = nl.l()[0];
+    const int jl = nl.l()[1];
 
     // second term of Eq. 2
     for (int is = 0; is < ctx__.num_spins(); is++) {
         for (int m1 = 0; m1 < 2 * jl + 1; m1++) {
             for (int m2 = 0; m2 < 2 * il + 1; m2++) {
-                hubbard_energy += v_ij_ * std::real(om__(m2, m1, is) * conj(om__(m2, m1, is)));
+                hubbard_energy += nl.V() * std::real(om__(m2, m1, is) * conj(om__(m2, m1, is)));
             }
         }
     }
