@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2016 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file xc_functional.hpp
  *
@@ -1422,7 +1411,7 @@ class XC_functional_base
         auto ns = (num_spins__ == 1) ? XC_UNPOLARIZED : XC_POLARIZED;
 
         if (libxc_name_ != "XC_GGA_DEBUG" && libxc_name_ != "XC_LDA_DEBUG") {
-            handler_ = std::unique_ptr<xc_func_type>(new xc_func_type);
+            handler_ = std::make_unique<xc_func_type>();
 
             /* init xc functional handler */
             if (xc_func_init(handler_.get(), libxc_functionals.at(libxc_name_), ns) != 0) {
@@ -1682,7 +1671,7 @@ class XC_functional_base
                 vsigma_dd[i] = vsigma[3 * i + 2];
             }
         } else {
-            auto h1 = std::unique_ptr<xc_func_type>(new xc_func_type);
+            auto h1 = std::make_unique<xc_func_type>();
 
             /* init xc functional handler */
             if (xc_func_init(h1.get(), XC_LDA_C_PZ, 2) != 0) {
