@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2017 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file spline.hpp
  *
@@ -228,11 +217,11 @@ class Spline : public Radial_grid<U>
         int j = this->index_of(x);
         if (j == -1) {
             std::stringstream s;
-            s << "spline::at_point() index of point is not found\n"
+            s << "index of point is not found\n"
               << "  x           : " << x << "\n"
               << "  first point : " << this->first() << "\n"
               << "  last point  : " << this->last();
-            throw std::runtime_error(s.str());
+            RTE_THROW(s);
         }
         U dx = x - (*this)[j];
         return (*this)(j, dx);
@@ -264,7 +253,7 @@ class Spline : public Radial_grid<U>
                 break;
             }
             default: {
-                throw std::runtime_error("wrong order of derivative");
+                RTE_THROW("wrong order of derivative");
                 break;
             }
         }
@@ -345,8 +334,8 @@ class Spline : public Radial_grid<U>
 
         if (info) {
             std::stringstream s;
-            s << "[sirius::Spline::interpolate] error in tridiagonal solver: " << info;
-            throw std::runtime_error(s.str());
+            s << "error in tridiagonal solver: " << info;
+            RTE_THROW(s);
         }
 
         for (int i = 0; i < ns - 1; i++) {
@@ -809,7 +798,7 @@ inner(Spline<T> const& f__, Spline<T> const& g__, int m__, int num_points__)
             }*/
 
         default: {
-            throw std::runtime_error("wrong r^m prefactor");
+            RTE_THROW("wrong r^m prefactor");
         }
     }
     return result;
