@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2017 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file atom.hpp
  *
@@ -153,8 +142,6 @@ class Atom
             RTE_THROW("not yet mpi parallel");
         }
 
-        splindex_block<> spl_lm(lmmax, n_blocks(comm__.size()), block_id(comm__.rank()));
-
         auto l_by_lm = sf::l_by_lm(lmax_pot_);
 
         h_radial_integrals_.zero();
@@ -162,6 +149,49 @@ class Atom
             b_radial_integrals_.zero();
         }
 
+        if (type().parameters().cfg().settings().simple_lapw_ri()) {
+            #pragma omp parallel for
+            for (int lm = 0; lm < lmmax; lm++) {
+                int l = l_by_lm[lm];
+
+                for (int i2 = 0; i2 < type().indexr().size(); i2++) {
+                    int l2 = type().indexr(i2).am.l();
+                    for (int i1 = 0; i1 <= i2; i1++) {
+                        int l1 = type().indexr(i1).am.l();
+                        if ((l + l1 + l2) % 2 == 0) {
+                            if (lm) {
+                                Spline<double> s(type().radial_grid());
+                                for (int ir = 0; ir < nmtp; ir++) {
+                                    s(ir) = veff_(lm, ir) * symmetry_class().radial_function(ir, i1) *
+                                            symmetry_class().radial_function(ir, i2) *
+                                            std::pow(type().radial_grid(ir), 2);
+                                }
+                                h_radial_integrals_(lm, i1, i2) = h_radial_integrals_(lm, i2, i1) =
+                                        s.interpolate().integrate(0);
+                            } else {
+                                h_radial_integrals_(lm, i1, i2) = symmetry_class().h_spherical_integral(i1, i2);
+                                h_radial_integrals_(lm, i2, i1) = symmetry_class().h_spherical_integral(i2, i1);
+                            }
+                            for (int j = 0; j < num_mag_dims; j++) {
+                                Spline<double> s(type().radial_grid());
+                                for (int ir = 0; ir < nmtp; ir++) {
+                                    s(ir) = beff_[j](lm, ir) * symmetry_class().radial_function(ir, i1) *
+                                            symmetry_class().radial_function(ir, i2) *
+                                            std::pow(type().radial_grid(ir), 2);
+                                }
+                                b_radial_integrals_(lm, i1, i2, j) = b_radial_integrals_(lm, i2, i1, j) =
+                                        s.interpolate().integrate(0);
+                            }
+                        }
+                    }
+                }
+            }
+
+            return;
+        }
+
+        splindex_block<> spl_lm(lmmax, n_blocks(comm__.size()), block_id(comm__.rank()));
+
         /* copy radial functions to spline objects */
         std::vector<Spline<double>> rf_spline(nrf);
         #pragma omp parallel for
@@ -364,6 +394,13 @@ class Atom
         return vector_field_;
     }
 
+    /// Set vector field.
+    inline void
+    set_vector_field(r3::vector<double> vector_field__)
+    {
+        vector_field_ = vector_field__;
+    }
+
     /// Return id of the symmetry class.
     inline int
     symmetry_class_id() const
