@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2022 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file atom_symmetry_class.cpp
  *
@@ -39,7 +28,7 @@ Atom_symmetry_class::Atom_symmetry_class(int id__, Atom_type const& atom_type__)
     int max_order = atom_type_.indexr().max_order();
     int nrf       = atom_type_.mt_radial_basis_size();
 
-    surface_derivatives_ = mdarray<double, 2>({3, nrf});
+    surface_derivatives_ = mdarray<double, 2>({3, atom_type_.mt_radial_basis_size() - atom_type_.num_lo_descriptors()});
 
     radial_functions_ = mdarray<double, 3>({atom_type_.num_mt_points(), nrf, 2});
 
@@ -70,109 +59,113 @@ Atom_symmetry_class::Atom_symmetry_class(int id__, Atom_type const& atom_type__)
     std::fill(ae_core_charge_density_.begin(), ae_core_charge_density_.end(), 0);
 }
 
-void
-Atom_symmetry_class::generate_aw_radial_functions(relativity_t rel__)
+int
+Atom_symmetry_class::generate_aw_radial_functions(relativity_t rel__, mdarray<double, 3>& rf__,
+                                                  mdarray<double, 2>& sd__) const
 {
     int nmtp = atom_type_.num_mt_points();
 
     Radial_solver solver(atom_type_.zn(), spherical_potential_, atom_type_.radial_grid());
 
-    #pragma omp parallel default(shared)
-    {
+    auto compute_all_orders = [&](int l, double enu_shift) -> bool {
         Spline<double> s(atom_type_.radial_grid());
 
-        std::vector<double> p;
-        std::vector<double> rdudr;
-        std::array<double, 2> uderiv;
+        for (int order = 0; order < (int)aw_descriptor(l).size(); order++) {
+            auto rsd = aw_descriptor(l)[order];
 
-        #pragma omp for schedule(dynamic, 1)
-        for (int l = 0; l < num_aw_descriptors(); l++) {
-            for (int order = 0; order < (int)aw_descriptor(l).size(); order++) {
-                auto rsd = aw_descriptor(l)[order];
+            auto idxrf = atom_type_.indexr().index_of(angular_momentum(l), order);
 
-                auto idxrf = atom_type_.indexr().index_of(angular_momentum(l), order);
+            /* integrate radial equation forward and find radial solution */
+            auto result = solver.solve(rel__, rsd.dme, rsd.l, rsd.enu + enu_shift);
 
-                solver.solve(rel__, rsd.dme, rsd.l, rsd.enu, p, rdudr, uderiv);
+            for (int ir = 0; ir < nmtp; ir++) {
+                rf__(ir, idxrf, 0) = result.p[ir];
+                rf__(ir, idxrf, 1) = result.rdudr[ir];
+            }
+            for (int i : {0, 1, 2}) {
+                sd__(i, idxrf) = result.uderiv[i];
+            }
 
-                /* normalize */
-                for (int ir = 0; ir < nmtp; ir++) {
-                    s(ir) = std::pow(p[ir], 2);
-                }
-                double norm = 1.0 / std::sqrt(s.interpolate().integrate(0));
+            /* orthogonalize to previous radial functions */
+            for (int order1 = 0; order1 < order; order1++) {
+                auto idxrf1 = atom_type_.indexr().index_of(angular_momentum(l), order1);
 
                 for (int ir = 0; ir < nmtp; ir++) {
-                    radial_functions_(ir, idxrf, 0) = p[ir] * norm;
-                    radial_functions_(ir, idxrf, 1) = rdudr[ir] * norm;
-                }
-                surface_derivatives_(0, idxrf) = norm * p.back() / atom_type_.mt_radius();
-                for (int i : {0, 1}) {
-                    surface_derivatives_(i + 1, idxrf) = uderiv[i] * norm;
+                    s(ir) = rf__(ir, idxrf, 0) * rf__(ir, idxrf1, 0);
                 }
 
-                /* orthogonalize to previous radial functions */
-                for (int order1 = 0; order1 < order; order1++) {
-                    auto idxrf1 = atom_type_.indexr().index_of(angular_momentum(l), order1);
-
-                    for (int ir = 0; ir < nmtp; ir++) {
-                        s(ir) = radial_functions_(ir, idxrf, 0) * radial_functions_(ir, idxrf1, 0);
-                    }
-
-                    /* <u_{\nu'}|u_{\nu}> */
-                    double ovlp = s.interpolate().integrate(0);
-
-                    for (int ir = 0; ir < nmtp; ir++) {
-                        radial_functions_(ir, idxrf, 0) -= radial_functions_(ir, idxrf1, 0) * ovlp;
-                        radial_functions_(ir, idxrf, 1) -= radial_functions_(ir, idxrf1, 1) * ovlp;
-                    }
-                    for (int i : {0, 1, 2}) {
-                        surface_derivatives_(i, idxrf) -= surface_derivatives_(i, idxrf1) * ovlp;
-                    }
-                }
-
-                /* normalize again */
-                for (int ir = 0; ir < nmtp; ir++) {
-                    s(ir) = std::pow(radial_functions_(ir, idxrf, 0), 2);
-                }
-                norm = s.interpolate().integrate(0);
-
-                if (std::abs(norm) < 1e-10) {
-                    std::stringstream s;
-                    s << "AW radial function for atom " << atom_type_.label() << " is linearly dependent" << std::endl
-                      << "  order: " << order << std::endl
-                      << "      l: " << l << std::endl
-                      << "    dme: " << rsd.dme << std::endl
-                      << "    enu: " << rsd.enu;
-                    RTE_THROW(s);
-                }
-
-                norm = 1.0 / std::sqrt(norm);
+                /* <u_{\nu'}|u_{\nu}> */
+                double ovlp = s.interpolate().integrate(0);
 
                 for (int ir = 0; ir < nmtp; ir++) {
-                    radial_functions_(ir, idxrf, 0) *= norm;
-                    radial_functions_(ir, idxrf, 1) *= norm;
+                    rf__(ir, idxrf, 0) -= rf__(ir, idxrf1, 0) * ovlp;
+                    rf__(ir, idxrf, 1) -= rf__(ir, idxrf1, 1) * ovlp;
                 }
                 for (int i : {0, 1, 2}) {
-                    surface_derivatives_(i, idxrf) *= norm;
+                    sd__(i, idxrf) -= sd__(i, idxrf1) * ovlp;
                 }
-            } // order
+            }
+
+            /* normalize orthogonal function */
+            for (int ir = 0; ir < nmtp; ir++) {
+                s(ir) = std::pow(rf__(ir, idxrf, 0), 2);
+            }
+            auto norm = s.interpolate().integrate(0);
+
+            /* in case of linear dependency continue to increase energy */
+            if (std::abs(norm) < 1e-8) {
+                return false;
+            }
+
+            norm = 1.0 / std::sqrt(norm);
+
+            for (int ir = 0; ir < nmtp; ir++) {
+                rf__(ir, idxrf, 0) *= norm;
+                rf__(ir, idxrf, 1) *= norm;
+            }
+            for (int i : {0, 1, 2}) {
+                sd__(i, idxrf) *= norm;
+            }
+        } // order
+        return true;
+    };
+
+    bool found{true};
+
+    #pragma omp parallel for schedule(dynamic, 1) default(shared)
+    for (int l = 0; l < num_aw_descriptors(); l++) {
+        /* try to increase linearisation energy several times in order to find linearly independent
+         * radial functions */
+        bool success{false};
+        for (int k = 0; k < 100; k++) {
+            if ((success = compute_all_orders(l, k * 0.5))) {
+                break;
+            }
+        }
+        if (success) {
             /* divide by r */
             for (int order = 0; order < (int)aw_descriptor(l).size(); order++) {
                 auto idxrf = atom_type_.indexr().index_of(angular_momentum(l), order);
                 for (int ir = 0; ir < nmtp; ir++) {
-                    radial_functions_(ir, idxrf, 0) *= atom_type_.radial_grid().x_inv(ir);
+                    rf__(ir, idxrf, 0) *= atom_type_.radial_grid().x_inv(ir);
                 }
             }
-        } // l
-    }
+        } else {
+            found = false;
+        }
+    } // l
+    return found ? 0 : 1;
 }
 
-void
-Atom_symmetry_class::generate_lo_radial_functions(relativity_t rel__)
+int
+Atom_symmetry_class::generate_lo_radial_functions(relativity_t rel__, mdarray<double, 3>& rf__) const
 {
     int nmtp = atom_type_.num_mt_points();
 
     Radial_solver solver(atom_type_.zn(), spherical_potential_, atom_type_.radial_grid());
 
+    bool found{true};
+
     #pragma omp parallel for schedule(dynamic, 1)
     for (int idxlo = 0; idxlo < num_lo_descriptors(); idxlo++) {
         Spline<double> s(atom_type_.radial_grid());
@@ -183,35 +176,27 @@ Atom_symmetry_class::generate_lo_radial_functions(relativity_t rel__)
         int num_rs = static_cast<int>(lo_descriptor(idxlo).rsd_set.size());
         RTE_ASSERT(num_rs <= 3);
 
-        std::vector<std::vector<double>> p(num_rs);
+        std::vector<std::vector<double>> u(num_rs);
         std::vector<std::vector<double>> rdudr(num_rs);
-        std::array<double, 2> uderiv;
 
         for (int order = 0; order < num_rs; order++) {
             auto rsd = lo_descriptor(idxlo).rsd_set[order];
 
-            solver.solve(rel__, rsd.dme, rsd.l, rsd.enu, p[order], rdudr[order], uderiv);
+            auto result = solver.solve(rel__, rsd.dme, rsd.l, rsd.enu);
 
-            /* find norm of the radial solution */
-            for (int ir = 0; ir < nmtp; ir++) {
-                s(ir) = std::pow(p[order][ir], 2);
-            }
-            double norm = 1.0 / std::sqrt(s.interpolate().integrate(0));
+            u[order]     = result.p;
+            rdudr[order] = result.rdudr;
 
-            /* normalize radial solution and divide by r */
+            /* divide by r */
             for (int ir = 0; ir < nmtp; ir++) {
                 /* store u(r) = p(r)/r */
-                p[order][ir] *= (norm * atom_type_.radial_grid().x_inv(ir));
-                /* don't divide rdudr by r */
-                rdudr[order][ir] *= norm;
+                u[order][ir] *= atom_type_.radial_grid().x_inv(ir);
             }
-            uderiv[0] *= norm;
-            uderiv[1] *= norm;
 
             /* matrix of derivatives */
-            a[order][0] = p[order].back();
-            a[order][1] = uderiv[0];
-            a[order][2] = uderiv[1];
+            a[order][0] = result.uderiv[0];
+            a[order][1] = result.uderiv[1];
+            a[order][2] = result.uderiv[2];
 
             for (int i : {0, 1, 2}) {
                 rderiv[order][i] = a[order][i];
@@ -241,39 +226,29 @@ Atom_symmetry_class::generate_lo_radial_functions(relativity_t rel__)
 
         /* index of local orbital radial function */
         auto idxrf = atom_type_.indexr().index_of(rf_lo_index(idxlo));
-        /* zero surface derivatives */
-        for (int i : {0, 1, 2}) {
-            surface_derivatives_(i, idxrf) = 0;
-        }
         /* take linear combination of radial solutions */
         for (int order = 0; order < num_rs; order++) {
             for (int ir = 0; ir < nmtp; ir++) {
                 /* u(r) function */
-                radial_functions_(ir, idxrf, 0) += b[order] * p[order][ir];
+                rf__(ir, idxrf, 0) += b[order] * u[order][ir];
                 /* r(du/dr) function */
-                radial_functions_(ir, idxrf, 1) += b[order] * rdudr[order][ir];
-            }
-            for (int i : {0, 1, 2}) {
-                surface_derivatives_(i, idxrf) += b[order] * rderiv[order][i];
+                rf__(ir, idxrf, 1) += b[order] * rdudr[order][ir];
             }
         }
 
         /* find norm of constructed local orbital */
         for (int ir = 0; ir < nmtp; ir++) {
-            s(ir) = std::pow(radial_functions_(ir, idxrf, 0), 2);
+            s(ir) = std::pow(rf__(ir, idxrf, 0), 2);
         }
         double norm = 1.0 / std::sqrt(s.interpolate().integrate(2));
 
         /* normalize */
         for (int ir = 0; ir < nmtp; ir++) {
-            radial_functions_(ir, idxrf, 0) *= norm;
-            radial_functions_(ir, idxrf, 1) *= norm;
-        }
-        for (int i : {0, 1, 2}) {
-            surface_derivatives_(i, idxrf) *= norm;
+            rf__(ir, idxrf, 0) *= norm;
+            rf__(ir, idxrf, 1) *= norm;
         }
 
-        if (std::abs(radial_functions_(nmtp - 1, idxrf, 0)) > 1e-10 || surface_derivatives_(0, idxrf) > 1e-10) {
+        if (std::abs(radial_functions_(nmtp - 1, idxrf, 0)) > 1e-10) {
             std::stringstream s;
             s << "local orbital " << idxlo << " is not zero at MT boundary" << std::endl
               << "  atom symmetry class id : " << id() << " (" << atom_type().symbol() << ")" << std::endl
@@ -285,14 +260,15 @@ Atom_symmetry_class::generate_lo_radial_functions(relativity_t rel__)
                 s << b[j] << " ";
             }
             s << std::endl;
-            s << "surface derivative : " << surface_derivatives_(0, idxrf);
             RTE_WARNING(s);
         }
     }
 
-    if (atom_type_.parameters().cfg().control().verification() > 0 && num_lo_descriptors() > 0) {
+    if (found && atom_type_.parameters().cfg().control().verification() > 0 && num_lo_descriptors() > 0) {
         check_lo_linear_independence(0.0001);
     }
+
+    return found ? 0 : 1;
 }
 
 void
@@ -317,9 +293,6 @@ Atom_symmetry_class::orthogonalize_radial_functions()
                     radial_functions_(ir, idxrf, 0) -= radial_functions_(ir, idxrf1, 0) * ovlp;
                     radial_functions_(ir, idxrf, 1) -= radial_functions_(ir, idxrf1, 1) * ovlp;
                 }
-                for (int i : {0, 1, 2}) {
-                    surface_derivatives_(i, idxrf) -= surface_derivatives_(i, idxrf1) * ovlp;
-                }
             }
             /* normalize again */
             for (int ir = 0; ir < nmtp; ir++) {
@@ -340,15 +313,12 @@ Atom_symmetry_class::orthogonalize_radial_functions()
                 radial_functions_(ir, idxrf, 0) *= norm;
                 radial_functions_(ir, idxrf, 1) *= norm;
             }
-            for (int i : {0, 1, 2}) {
-                surface_derivatives_(i, idxrf) *= norm;
-            }
         }
     }
 }
 
 std::vector<int>
-Atom_symmetry_class::check_lo_linear_independence(double tol__)
+Atom_symmetry_class::check_lo_linear_independence(double tol__) const
 {
     int nmtp = atom_type_.num_mt_points();
 
@@ -523,14 +493,11 @@ Atom_symmetry_class::find_enu(relativity_t rel__)
     for (size_t i = 0; i < rs_with_auto_enu.size(); i++) {
         auto rsd       = rs_with_auto_enu[i];
         double new_enu = Enu_finder(rel__, atom_type_.zn(), rsd->n, rsd->l, atom_type_.radial_grid(),
-                                    spherical_potential_, rsd->enu)
+                                    spherical_potential_, rsd->enu, rsd->auto_enu)
                                  .enu();
         /* update linearization energy only if its change is above a threshold */
         if (std::abs(new_enu - rsd->enu) > atom_type_.parameters().cfg().settings().auto_enu_tol()) {
-            rsd->enu           = new_enu;
-            rsd->new_enu_found = true;
-        } else {
-            rsd->new_enu_found = false;
+            rsd->enu = new_enu;
         }
     }
 }
@@ -540,32 +507,67 @@ Atom_symmetry_class::generate_radial_functions(relativity_t rel__)
 {
     PROFILE("sirius::Atom_symmetry_class::generate_radial_functions");
 
-    radial_functions_.zero();
+    mdarray<double, 2> sd({3, atom_type_.mt_radial_basis_size() - atom_type_.num_lo_descriptors()});
+    mdarray<double, 3> rf({atom_type_.num_mt_points(), atom_type_.mt_radial_basis_size(), 2});
+    sd.zero();
+    rf.zero();
 
     find_enu(rel__);
 
-    generate_aw_radial_functions(rel__);
+    auto ierr = generate_aw_radial_functions(rel__, rf, sd);
+    if (ierr) {
+        std::stringstream s;
+        s << "generate_aw_radial_functions() failed for atom class " << id_;
+        RTE_WARNING(s);
+    }
 
-    generate_lo_radial_functions(rel__);
+    auto ierr1 = generate_lo_radial_functions(rel__, rf);
+    if (ierr1) {
+        std::stringstream s;
+        s << "generate_lo_radial_functions() failed for atom class " << id_;
+        RTE_WARNING(s);
+    }
 
-    if (atom_type().parameters().cfg().control().ortho_rf()) {
-        orthogonalize_radial_functions();
+    ierr += ierr1;
+
+    if (!ierr) {
+        copy(rf, radial_functions_);
+        copy(sd, surface_derivatives_);
+        if (atom_type().parameters().cfg().control().ortho_rf()) {
+            orthogonalize_radial_functions();
+        }
     }
 
     if (atom_type().parameters().cfg().control().save_rf()) {
-        std::stringstream s;
-        s << "radial_functions_" << id_ << ".dat";
-        FILE* fout = fopen(s.str().c_str(), "w");
+        static int count{0};
 
-        for (int ir = 0; ir < atom_type_.num_mt_points(); ir++) {
-            fprintf(fout, "%20.15f ", atom_type_.radial_grid(ir));
-            for (int idxrf = 0; idxrf < atom_type_.indexr().size(); idxrf++) {
-                fprintf(fout, "%20.15f ", radial_functions_(ir, idxrf, 0));
-                fprintf(fout, "%20.15f ", radial_functions_(ir, idxrf, 1));
+        if (true) {
+            std::stringstream s;
+            s << "radial_functions_class_" << id_ << "_step_" << count << ".dat";
+            std::ofstream ofs(s.str(), std::ofstream::out | std::ofstream::trunc);
+
+            for (int ir = 0; ir < atom_type_.num_mt_points(); ir++) {
+                ofs << std::setprecision(12) << atom_type_.radial_grid(ir) << " ";
+                for (int idxrf = 0; idxrf < atom_type_.indexr().size(); idxrf++) {
+                    ofs << std::setprecision(12) << radial_functions_(ir, idxrf, 0) << " "
+                        << radial_functions_(ir, idxrf, 1) << " ";
+                }
+                ofs << std::endl;
             }
-            fprintf(fout, "\n");
         }
-        fclose(fout);
+
+        if (true) {
+            std::stringstream s;
+            s << "radial_potential_class_" << id_ << "_step_" << count << ".dat";
+            std::ofstream ofs(s.str(), std::ofstream::out | std::ofstream::trunc);
+
+            for (int ir = 0; ir < atom_type_.num_mt_points(); ir++) {
+                ofs << std::setprecision(12) << atom_type_.radial_grid(ir) << " " << spherical_potential_[ir] << " "
+                    << spherical_potential_[ir] + atom_type_.zn() / atom_type_.radial_grid(ir) << std::endl;
+            }
+        }
+
+        count++;
     }
 }
 
@@ -652,10 +654,18 @@ Atom_symmetry_class::generate_radial_integrals(relativity_t rel__)
                     if (order1 == order2) {
                         o_radial_integrals_(l, order1, order2) = 1.0;
                     } else {
-                        for (int ir = 0; ir < nmtp; ir++) {
-                            s(ir) = radial_functions_(ir, idxrf1, 0) * radial_functions_(ir, idxrf2, 0);
+                        if (atom_type_.parameters().cfg().settings().simple_lapw_ri()) {
+                            for (int ir = 0; ir < nmtp; ir++) {
+                                s(ir) = radial_functions_(ir, idxrf1, 0) * radial_functions_(ir, idxrf2, 0) *
+                                        std::pow(atom_type_.radial_grid(ir), 2);
+                            }
+                            o_radial_integrals_(l, order1, order2) = s.interpolate().integrate(0);
+                        } else {
+                            for (int ir = 0; ir < nmtp; ir++) {
+                                s(ir) = radial_functions_(ir, idxrf1, 0) * radial_functions_(ir, idxrf2, 0);
+                            }
+                            o_radial_integrals_(l, order1, order2) = s.interpolate().integrate(2);
                         }
-                        o_radial_integrals_(l, order1, order2) = s.interpolate().integrate(2);
                     }
                 }
             }
@@ -671,12 +681,12 @@ Atom_symmetry_class::generate_radial_integrals(relativity_t rel__)
                 if (atom_type_.indexr(i1).am.l() == atom_type_.indexr(i2).am.l()) {
                     int ll = atom_type_.indexr(i1).am.l() * (atom_type_.indexr(i1).am.l() + 1);
                     for (int ir = 0; ir < nmtp; ir++) {
-                        double Minv = std::pow(1 - spherical_potential_[ir] * sq_alpha_half, -2);
+                        double Minv2 = std::pow(1 - spherical_potential_[ir] * sq_alpha_half, -2);
                         /* u_1(r) * u_2(r) */
                         double t0 = radial_functions_(ir, i1, 0) * radial_functions_(ir, i2, 0);
                         /* r*u'_1(r) * r*u'_2(r) */
                         double t1 = radial_functions_(ir, i1, 1) * radial_functions_(ir, i2, 1);
-                        s(ir)     = sq_alpha_half * 0.5 * Minv * (t1 + t0 * 0.5 * ll);
+                        s(ir)     = sq_alpha_half * 0.5 * Minv2 * (t1 + t0 * ll);
                     }
                     o1_radial_integrals_(i1, i2) = s.interpolate().integrate(0);
                 }
@@ -734,11 +744,7 @@ Atom_symmetry_class::write_enu(mpi::pstdout& pout) const
         for (size_t order = 0; order < aw_descriptor(l).size(); order++) {
             auto& rsd = aw_descriptor(l)[order];
             if (rsd.auto_enu) {
-                pout << rsd; // printf("n = %2i   l = %2i   order = %i   enu = %12.6f", rsd.n, rsd.l, order, rsd.enu);
-                if (rsd.new_enu_found) {
-                    pout << "  +";
-                }
-                pout << std::endl;
+                pout << rsd << std::endl;
             }
         }
     }
@@ -748,12 +754,7 @@ Atom_symmetry_class::write_enu(mpi::pstdout& pout) const
         for (size_t order = 0; order < lo_descriptor(idxlo).rsd_set.size(); order++) {
             auto& rsd = lo_descriptor(idxlo).rsd_set[order];
             if (rsd.auto_enu) {
-                // pout.printf("n = %2i   l = %2i   order = %i   enu = %12.6f", rsd.n, rsd.l, order, rsd.enu);
-                pout << rsd;
-                if (rsd.new_enu_found) {
-                    pout << "  +";
-                }
-                pout << std::endl;
+                pout << rsd << std::endl;
             }
         }
     }
