@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2016 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file atom_symmetry_class.hpp
  *
@@ -44,11 +33,11 @@ class Atom_symmetry_class
     /// List of atoms of this class.
     std::vector<int> atom_id_;
 
-    /// Pointer to atom type.
+    /// Reference to atom type.
     Atom_type const& atom_type_;
 
     /// Spherical part of the effective potential.
-    /** Used by the LAPW radial solver. */
+    /** Used by the LAPW radial solver. Actual value is stored, not the Y00 component. */
     std::vector<double> spherical_potential_;
 
     /// List of radial functions for the LAPW basis.
@@ -92,12 +81,12 @@ class Atom_symmetry_class
     mutable std::vector<local_orbital_descriptor> lo_descriptors_;
 
     /// Generate radial functions for augmented waves
-    void
-    generate_aw_radial_functions(relativity_t rel__);
+    int
+    generate_aw_radial_functions(relativity_t rel__, mdarray<double, 3>& rf__, mdarray<double, 2>& sd__) const;
 
     /// Generate local orbital raidal functions
-    void
-    generate_lo_radial_functions(relativity_t rel__);
+    int
+    generate_lo_radial_functions(relativity_t rel__, mdarray<double, 3>& rf__) const;
 
     /// Orthogonalize the radial functions.
     void
@@ -127,7 +116,7 @@ class Atom_symmetry_class
 
     /// Check if local orbitals are linearly independent
     std::vector<int>
-    check_lo_linear_independence(double etol__);
+    check_lo_linear_independence(double etol__) const;
 
     /// Dump local orbitals to the file for debug purposes
     void
@@ -172,8 +161,7 @@ class Atom_symmetry_class
     aw_surface_deriv(int l__, int order__, int dm__, double deriv__)
     {
         RTE_ASSERT(dm__ <= 2);
-        auto idxrf                        = atom_type_.indexr().index_of(angular_momentum(l__), order__);
-        surface_derivatives_(dm__, idxrf) = deriv__;
+        surface_derivatives_(dm__, atom_type_.indexr().index_of(angular_momentum(l__), order__)) = deriv__;
     }
 
     /// Return symmetry class id.
