@@ -1,21 +1,10 @@
-// Copyright (c) 2013-2021 Anton Kozhevnikov, Thomas Schulthess
-// All rights reserved.
-//
-// Redistribution and use in source and binary forms, with or without modification, are permitted provided that
-// the following conditions are met:
-//
-// 1. Redistributions of source code must retain the above copyright notice, this list of conditions and the
-//    following disclaimer.
-// 2. Redistributions in binary form must reproduce the above copyright notice, this list of conditions
-//    and the following disclaimer in the documentation and/or other materials provided with the distribution.
-//
-// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED
-// WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
-// PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
-// ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-// PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
-// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+/* This file is part of SIRIUS electronic structure library.
+ *
+ * Copyright (c), ETH Zurich.  All rights reserved.
+ *
+ * Please, refer to the LICENSE file in the root directory.
+ * SPDX-License-Identifier: BSD-3-Clause
+ */
 
 /** \file unit_cell.cpp
  *
@@ -631,7 +620,7 @@ Atom_type&
 Unit_cell::add_atom_type(const std::string label__, const std::string file_name__)
 {
     int id = next_atom_type_id(label__);
-    atom_types_.push_back(std::shared_ptr<Atom_type>(new Atom_type(parameters_, id, label__, file_name__)));
+    atom_types_.push_back(std::make_shared<Atom_type>(parameters_, id, label__, file_name__));
     return *atom_types_.back();
 }
 
@@ -650,7 +639,7 @@ Unit_cell::add_atom(const std::string label, r3::vector<double> position, r3::ve
         RTE_THROW(s);
     }
 
-    atoms_.push_back(std::shared_ptr<Atom>(new Atom(atom_type(label), position, vector_field)));
+    atoms_.push_back(std::make_shared<Atom>(atom_type(label), position, vector_field));
     atom_type(label).add_atom_id(static_cast<int>(atoms_.size()) - 1);
 }
 
@@ -752,9 +741,9 @@ Unit_cell::get_symmetry()
         types[ia] = atom(ia).type_id();
     }
 
-    symmetry_ = std::unique_ptr<Crystal_symmetry>(new Crystal_symmetry(
-            lattice_vectors_, num_atoms(), num_atom_types(), types, positions, spins, parameters_.so_correction(),
-            parameters_.spglib_tolerance(), parameters_.use_symmetry()));
+    symmetry_ = std::make_unique<Crystal_symmetry>(lattice_vectors_, num_atoms(), num_atom_types(), types, positions,
+                                                   spins, parameters_.so_correction(), parameters_.spglib_tolerance(),
+                                                   parameters_.use_symmetry());
 
     int atom_class_id{-1};
     std::vector<int> asc(num_atoms(), -1);
@@ -763,8 +752,7 @@ Unit_cell::get_symmetry()
         if (asc[i] == -1) {
             /* take next id */
             atom_class_id++;
-            atom_symmetry_classes_.push_back(
-                    std::shared_ptr<Atom_symmetry_class>(new Atom_symmetry_class(atom_class_id, atom(i).type())));
+            atom_symmetry_classes_.push_back(std::make_shared<Atom_symmetry_class>(atom_class_id, atom(i).type()));
 
             /* scan all atoms */
             for (int j = 0; j < num_atoms(); j++) {
